@@ -751,10 +751,10 @@ class ModelSet:
             df.columns = ["help"]
             return df
 
-    def pe_dataset(self, ticker, yahoo_ticker):
+    def pe_dataset(self, ticker, yahoo_ticker, index_ticker="^GSPC", n_periods=24):
         import canalyst_candas.candas_datareader as cdr
 
-        df_earnings = cdr.get_earnings_and_prices(yahoo_ticker)
+        df_earnings = cdr.get_earnings_and_prices(yahoo_ticker, index_ticker)
         df_earnings = df_earnings[
             ["ticker", "earnings_date", "beta_252", "alpha_5_day", "alpha_10_day"]
         ]
@@ -768,13 +768,23 @@ class ModelSet:
                 "earnings_date_CALENDAR_QUARTER"
             ]
         )
+
         mdq_list = list(
             df_model.groupby("period_name_sorted")
             .first()
             .reset_index()
-            .sort_values("period_name_sorted", ascending=False)["period_name_sorted"]
+            .sort_values("period_end_date", ascending=False)["period_name_sorted"]
         )
-        d = {"earnings_date_q": edq_list[0:24], "period_name_sorted": mdq_list[0:24]}
+
+        if len(edq_list) < n_periods:
+            n_periods = len(edq_list)
+            print("Using " + str(n_periods) + " periods available")
+
+        d = {
+            "earnings_date_q": edq_list[0:n_periods],
+            "period_name_sorted": mdq_list[0:n_periods],
+        }
+
         df_dates = pd.DataFrame(d)
         df_model = pd.merge(df_model, df_dates)
         df_earnings["earnings_date_q"] = cdr.calendar_quarter(
@@ -798,50 +808,7 @@ class ModelSet:
                 "time_series_slug",
             ]
         )
-
-        df_data["year_over_year"] = (
-            df_data.sort_values(["time_series_name", "period_end_date"])
-            .groupby(["time_series_name"])
-            .value.pct_change(periods=4)
-        )
-
-        df_data["year_over_year_yoy"] = (
-            df_data.sort_values(["time_series_name", "period_end_date"])
-            .groupby(["time_series_name"])
-            .year_over_year.pct_change(periods=4)
-        )
-
-        df_data["quarter_over_quarter"] = (
-            df_data.sort_values(["time_series_name", "period_end_date"])
-            .groupby(["time_series_name"])
-            .value.pct_change(periods=1)
-        )
-
-        df_data["quarter_over_quarter_yoy"] = (
-            df_data.sort_values(["time_series_name", "period_end_date"])
-            .groupby(["time_series_name"])
-            .quarter_over_quarter.pct_change(periods=4)
-        )
-
-        df1 = df_data.copy()
-        df1["value"] = df1["year_over_year"]
-        df1["time_series_name"] = df1["time_series_name"] + "_year_over_year"
-
-        df2 = df_data.copy()
-        df2["value"] = df2["year_over_year_yoy"]
-        df2["time_series_name"] = df2["time_series_name"] + "_year_over_year_yoy"
-        df3 = df_data.copy()
-        df3["value"] = df3["quarter_over_quarter"]
-        df3["time_series_name"] = df3["time_series_name"] + "_quarter_over_quarter"
-        df4 = df_data.copy()
-        df4["value"] = df4["quarter_over_quarter_yoy"]
-        df4["time_series_name"] = df4["time_series_name"] + "_quarter_over_quarter_yoy"
-        # df_data = df_data.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
-        # df1 = df1.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
-        # df2 = df2.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
-        # df3 = df3.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
-        df_out = pd.concat([df_data, df1, df2, df3, df4])
-        return df_out[~df_out["value"].isna()]
+        return df_data
 
     def regress_dataframe_time_series_groups(
         self, df_data=None, y_name="alpha_10_day", return_grouped=True
@@ -1056,6 +1023,7 @@ class ModelSet:
         unit_type="",
         category="",
         warning=True,
+        mo_only="",
         ticker="",
     ):
 
@@ -1077,6 +1045,7 @@ class ModelSet:
             mrq_notation,
             unit_type,
             category,
+            mo_only,
             warning,
         )
 
