@@ -165,7 +165,9 @@ def get_beta_data(ticker, df_wide, betas_list):
     return df
 
 
-def get_price_data(ticker, reset=False, rolling_betas=True, rolling_window=60):
+def get_price_data(
+    ticker, reset=False, rolling_betas=True, rolling_window=60, index_ticker="^GSPC"
+):
     price_data = si.get_data(ticker, start_date="01/01/2009")
     df = pd.DataFrame(price_data)
     df = df[["adjclose"]]
@@ -181,7 +183,7 @@ def get_price_data(ticker, reset=False, rolling_betas=True, rolling_window=60):
         df["adjclose_plus_5"] = df["adjclose"].shift(-5)
         df["adjclose_plus_10"] = df["adjclose"].shift(-10)
 
-        sp_ticker = "^GSPC"
+        sp_ticker = index_ticker
         sp_data = si.get_data(sp_ticker, start_date="01/01/2009")
         df_sp = pd.DataFrame(sp_data)
         df_sp = df_sp[["adjclose"]]
@@ -360,6 +362,10 @@ def get_earnings_dates(ticker):
 def regress_dataframe(df, y_col, x_col, y_filter, sort_col="", n=24):
     import datetime as ddt
 
+    if df.dropna().shape[0] == 0:
+        print("Not enough datapoints")
+        return
+
     if y_filter != "":
         df = df.loc[df[y_col] == y_filter]
 
@@ -377,10 +383,14 @@ def regress_dataframe(df, y_col, x_col, y_filter, sort_col="", n=24):
     return predictions
 
 
-def get_earnings_and_prices(ticker):
+def get_earnings_and_prices(ticker, index_ticker):
     df_earnings = get_earnings_dates(ticker)
     df_prices = get_price_data(
-        ticker, reset=True, rolling_betas=True, rolling_window=252
+        ticker,
+        reset=True,
+        rolling_betas=True,
+        rolling_window=252,
+        index_ticker=index_ticker,
     )
     df = pd.merge(
         df_prices,
@@ -504,7 +514,9 @@ def plot_prices_against_time_series(
     config_ticks = {"size": 14, "color": colors["grey"], "labelcolor": colors["grey"]}
     config_title = {"size": 18, "color": colors["grey"], "ha": "left", "va": "baseline"}
 
-    fig, axes = plt.subplots(2, 1, gridspec_kw={"height_ratios": [3, 1]})
+    # fig, (ax1, ax2, ax3) = plt.subplots(nrows=3, sharex=True)
+
+    fig, axes = plt.subplots(2, 1, gridspec_kw={"height_ratios": [3, 1]}, sharex=True)
     fig.tight_layout(pad=3)
 
     date = df_plot["price_date"]
@@ -596,12 +608,18 @@ def regress_dataframe_time_series_groups(
     use_qoq_deltas=False,
     use_yoy_deltas=False,
     category_filter=[],
+    category="",
     n_periods=16,
 ):
 
     if len(category_filter):
         df_data = df_data.loc[~df_data["category"].isin(category_filter)]
 
+    if type(category) is list:
+        df_data = df_data.loc[df_data["category"].isin(category)]
+    elif category != "":
+        df_data = df_data.loc[df_data["category"] == category]
+
     if use_qoq_deltas == False:
         df_data = df_data.loc[
             ~df_data["time_series_name"].str.contains("quarter_over_quarter")
@@ -618,8 +636,12 @@ def regress_dataframe_time_series_groups(
         df_data, y_name=y_name, return_grouped=return_grouped, n_periods=n_periods
     )
 
+    if df is None:
+        print("Regression error: perhaps not enough datapoints")
+        return
+
     df["ticker"] = ticker
-    df["model_row_number"] = df["model_row_number"].astype(int)
+    df["name_index"] = df["name_index"].astype(int)
     col_name = "ticker"
     first_col = df.pop(col_name)
     df.insert(0, col_name, first_col)
@@ -631,6 +653,14 @@ def regress_dataframe_time_series_groups(
 
 def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=12):
 
+    period_names = list(
+        df_data.groupby("period_name")
+        .first()
+        .sort_values("period_end_date")
+        .reset_index()
+        .tail(n_periods)["period_name"]
+    )
+
     warnings.filterwarnings("ignore", category=RuntimeWarning)
 
     # return df_data
@@ -640,7 +670,12 @@ def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=
     # return df_data
 
     def extract_lr(x, y_name):
-        x = x.tail(n_periods)
+        x = x.loc[x["period_name"].isin(period_names)]
+        x = x[x["value"].notna()]
+
+        if x.shape[0] != n_periods:
+            return None
+
         model = smf.ols(formula="value ~ alpha_10_day", data=x)
         rres = model.fit()
 
@@ -654,39 +689,42 @@ def regress_dataframe_groups(df_data, y_name="", return_grouped=True, n_periods=
     grouped = grouped.apply(lambda x: extract_lr(x, y_name))
 
     if return_grouped == True:
-        df_output = (
-            grouped.reset_index(drop=True)
-            .groupby(
+        try:
+            df_output = (
+                grouped.reset_index(drop=True)
+                .groupby(
+                    [
+                        "name_index",
+                        "time_series_description",
+                        "time_series_name",
+                        "category",
+                    ]
+                )
+                .mean()
+                .reset_index()
+                .sort_values("rsquared", ascending=False)
+            )
+            df_output = df_output.loc[df_output["n_periods"] >= n_periods]
+            return df_output[
                 [
                     "name_index",
                     "time_series_description",
                     "time_series_name",
                     "category",
+                    "rsquared",
+                    "slope",
+                    "intercept",
+                    "n_periods",
                 ]
-            )
-            .mean()
-            .reset_index()
-            .sort_values("rsquared", ascending=False)
-        )
-        df_output["model_row_number"] = df_output["name_index"]
-        df_output = df_output.loc[df_output["n_periods"] >= n_periods]
-        return df_output[
-            [
-                "model_row_number",
-                "time_series_description",
-                "time_series_name",
-                "category",
-                "rsquared",
-                "slope",
-                "intercept",
-                "n_periods",
             ]
-        ]
+        except:
+            print("Regression error")
     else:
         return grouped
 
 
 def rolling_r_squared(df_data, time_series_name, window, plot=False):
+    # df_data = df_data.sort_values('period_end_date',ascending=False)
     category_filter = []
     df = df_data[
         df_data["time_series_name"] == time_series_name
@@ -701,24 +739,48 @@ def rolling_r_squared(df_data, time_series_name, window, plot=False):
     df["intercept"] = rres.params[["Intercept"]]
     df["slope"] = rres.params[["alpha_10_day"]]
     df["rsquared"] = rres.rsquared
-    df = df[["alpha_10_day", "value", "slope", "rsquared", "intercept"]].dropna()
+    df = df[
+        [
+            "period_name",
+            "earnings_date",
+            "alpha_10_day",
+            "value",
+            "slope",
+            "rsquared",
+            "intercept",
+        ]
+    ].dropna()
     if plot == False:
         return df
 
     import matplotlib.pyplot as plt
 
-    fig, (ax1, ax2, ax3) = plt.subplots(nrows=3, sharex=True)
+    colors = {
+        "red": "#ff207c",
+        "grey": "#42535b",
+        "blue": "#207cff",
+        "orange": "#ffa320",
+        "green": "#00ec8b",
+    }
+    plt.rc("figure", figsize=(10, 7))
 
-    ax1.plot(df["slope"], label="Regression Slope")
+    fig, (ax1, ax2, ax3) = plt.subplots(nrows=3, sharex=True)
+    fig.tight_layout(pad=3)
+
+    ax1.plot(df["slope"], label="Regression Slope", color=colors["blue"])
     ax1.legend(loc="upper left")
 
-    ax2.plot(df["rsquared"], label="R Squared")
+    ax2.plot(df["rsquared"], label="R Squared", color=colors["blue"])
     ax2.legend(loc="upper left")
 
-    ax3.plot(df["value"], label="Time Series Value")
+    ax3.plot(df["value"], label="Time Series Value", color=colors["blue"])
     ax3.legend(loc="upper left")
 
     ax1.get_shared_x_axes().join(ax1, ax2, ax3)
     ax1.set_xticklabels([])
     ax1.title.set_text(time_series_name)
+    format_borders(ax1, colors)
+    format_borders(ax2, colors)
+    format_borders(ax3, colors)
+
     plt.show()
