@@ -197,6 +197,7 @@ def filter_dataset(
     mrq_notation=False,
     unit_type="",
     category="",
+    mo_only="",
     warning=True,
 ):
 
@@ -211,13 +212,21 @@ def filter_dataset(
             "period_duration_type = 'fiscal_year' to filter."
         )
 
+    if mo_only == True:
+        df = df.loc[df["time_series_name"].str.startswith("MO_")]
+        # df = df.loc[~df["time_series_name"].str.contains("_MO_")]
+    if mo_only == False:
+        df = df.loc[~df["time_series_name"].str.startswith("MO_")]
+
     if mrq is True:
         mrq = df["MRQ"].iloc[0]
         df = df.loc[df["period_name"] == df["MRQ"]]
 
     df = df.sort_values(["period_end_date", "name_index"])
 
-    if category != "":
+    if type(category) is list:
+        df = df.loc[df["category"].isin(category)]
+    elif category != "":
         df = df.loc[df["category"] == category]
 
     if period_name != "":
@@ -548,17 +557,20 @@ def get_company_info_from_ticker(ticker, auth_headers, mds_host=settings.MDS_HOS
 
 def get_csin_from_ticker(ticker, auth_headers, mds_host=settings.MDS_HOST):
     company_url = f"{mds_host}/{CSIN_URL.format(ticker=quote_plus(ticker))}"
-    response = requests.get(company_url, headers=auth_headers)
+    response = requests.get(company_url, headers=auth_headers, verify=False)
     json = response.json().get("results")[0]
     csin = json.get("csin")
     return csin
 
 
-def get_excel_model(ticker, config):
+def get_excel_model(ticker, config, download_dir=""):
     auth_headers = get_api_headers(config.canalyst_api_key)
     mds_host = config.mds_host
     wp_host = config.wp_host
-    default_dir = config.default_dir
+    if download_dir == "":
+        default_dir = config.default_dir
+    else:
+        default_dir = download_dir
 
     csin = get_csin_from_ticker(ticker, auth_headers, mds_host)
 
